@@ -1,12 +1,14 @@
+from azure.identity import DefaultAzureCredential
 from azure.mgmt.trafficmanager import TrafficManagerManagementClient
+from azure.mgmt.trafficmanager.models import CheckTrafficManagerRelativeDnsNameAvailabilityParameters
 
-from subdomain_takeover_tools.helper.credential_wrapper import CredentialWrapper
 from subdomain_takeover_tools.helper.main import bootstrap, settings
 from subdomain_takeover_tools.helper.prepare import resolve_cname
 
 TRAFFICMANAGER_NET = '.trafficmanager.net'
 
-credential = CredentialWrapper()
+credential = DefaultAzureCredential()
+
 tm_client = TrafficManagerManagementClient(credential, settings['azure']['subscription_id'])
 
 
@@ -24,8 +26,10 @@ def confirm_azure_traffic_manager(cname):
     if TRAFFICMANAGER_NET in cname:
         dns_prefix = cname.replace(TRAFFICMANAGER_NET, '')
         result = tm_client.profiles.check_traffic_manager_relative_dns_name_availability(
-            dns_prefix,
-            "microsoft.network/trafficmanagerprofiles"
+            parameters=CheckTrafficManagerRelativeDnsNameAvailabilityParameters(
+                name=dns_prefix,
+                type="microsoft.network/trafficmanagerprofiles"
+            )
         )
         return result.name_available
     return False
